@@ -7,6 +7,7 @@ from typing import (
     Dict,
     List,
     Literal,
+    Mapping,
     Optional,
     Sequence,
     Type,
@@ -83,6 +84,10 @@ class StrawberryDjangoField(_StrawberryDjangoField):
         )
         super().__init__(*args, **kwargs)
 
+    @cached_property
+    def is_basic_field(self):
+        return False
+
     @property
     def arguments(self) -> List[StrawberryArgument]:
         if isinstance(self, relay.NodeField):
@@ -290,6 +295,10 @@ class StrawberryDjangoNodeField(relay.NodeField, StrawberryDjangoField):
 
 
 class StrawberryDjangoConnectionField(relay.ConnectionField, StrawberryDjangoField):
+    def __init__(self, *args, **kwargs):
+        self._force_is_list_as_true = False
+        super().__init__(*args, **kwargs)
+
     @property
     def arguments(self) -> List[StrawberryArgument]:
         # FIXME: The order/filters/etc arguments will only be added if there's no base_resolver
@@ -297,12 +306,19 @@ class StrawberryDjangoConnectionField(relay.ConnectionField, StrawberryDjangoFie
         # return value itself. How to handle this in a better way?
         base_resolver = self._base_resolver
         self._base_resolver = None
+        self._force_is_list_as_true = True
         args = super().arguments
         if base_resolver is not None:
             args += base_resolver.arguments
         self._base_resolver = base_resolver
+        self._force_is_list_as_true = False
         return args
 
+    def is_list(self):
+        if self._force_is_list_as_true:
+            return True
+        return super().is_list
+
     def resolve_nodes(
         self,
         source: Any,
@@ -336,7 +352,8 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
@@ -360,7 +377,8 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
@@ -384,7 +402,8 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
@@ -407,7 +426,8 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
@@ -419,7 +439,7 @@ def field(
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
-    init=None,
+    init: Literal[True, False, None] = None,
 ) -> Any:
     """Annotate a method or property as a Django GraphQL field.
 
@@ -446,6 +466,7 @@ def field(
         deprecation_reason=deprecation_reason,
         default=default,
         default_factory=default_factory,
+        metadata=metadata,
         directives=directives,
         filters=filters,
         pagination=pagination,
@@ -469,6 +490,7 @@ def node(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
@@ -477,7 +499,7 @@ def node(
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
-    init=None,
+    init: Literal[True, False, None] = None,
 ) -> Any:
     """Annotate a property to create a relay query field.
 
@@ -510,6 +532,7 @@ def node(
         deprecation_reason=deprecation_reason,
         default=default,
         default_factory=default_factory,
+        metadata=metadata,
         directives=directives or (),
         only=only,
         select_related=select_related,
@@ -529,7 +552,8 @@ def connection(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
@@ -551,7 +575,8 @@ def connection(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
@@ -573,7 +598,8 @@ def connection(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
@@ -594,7 +620,8 @@ def connection(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
@@ -605,7 +632,7 @@ def connection(
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
-    init=None,
+    init: Literal[True, False, None] = None,
 ) -> Any:
     """Annotate a property or a method to create a relay connection field.
 
@@ -667,6 +694,7 @@ def connection(
         deprecation_reason=deprecation_reason,
         default=default,
         default_factory=default_factory,
+        metadata=metadata,
         directives=directives or (),
         filters=filters,
         order=order,
