@@ -1,6 +1,8 @@
+from enum import Enum
 from typing import Any, Callable, Optional, Sequence, Type, TypeVar, cast
 
 from django.db.models.base import Model
+from django.db.models.sql.query import get_field_names_from_opts  # type:ignore
 from strawberry import UNSET
 from strawberry.field import StrawberryField
 from strawberry.utils.typing import __dataclass_transform__
@@ -33,22 +35,30 @@ def _build_filter_kwargs(filters):
         field_name = f.name
         field_value = _normalize_value(getattr(filters, field_name))
 
+        if callable(field_value):
+            field_value = field_value()
+
         # Unset means we are not filtering this. None is still acceptable
         if field_value is UNSET:
             continue
 
+        if isinstance(field_value, Enum):
+            field_value = field_value.value
+
         field_name = _filters.lookup_name_conversion_map.get(field_name, field_name)
         filter_method = getattr(filters, f"filter_{field_name}", None)
         if filter_method:
             filter_methods.append(filter_method)
             continue
 
-        if django_model and field_name not in django_model._meta._forward_fields_map:  # type:ignore
+        if django_model and field_name not in get_field_names_from_opts(django_model._meta):
             continue
 
         if utils.is_strawberry_type(field_value):
             subfield_filter_kwargs, subfield_filter_methods = _build_filter_kwargs(field_value)
             for subfield_name, subfield_value in subfield_filter_kwargs.items():
+                if isinstance(subfield_value, Enum):
+                    subfield_value = subfield_value.value
                 filter_kwargs[f"{field_name}__{subfield_name}"] = subfield_value
 
             filter_methods.extend(subfield_filter_methods)
