@@ -2,7 +2,6 @@ import dataclasses
 import types
 from typing import (
     Callable,
-    Generic,
     Literal,
     Optional,
     Sequence,
@@ -14,7 +13,7 @@ from typing import (
     get_origin,
 )
 
-from django.contrib.contenttypes.fields import GenericRel
+from django.contrib.contenttypes.fields import GenericForeignKey, GenericRel
 from django.core.exceptions import FieldDoesNotExist
 from django.db.models.base import Model
 from django.db.models.fields.reverse_related import ManyToManyRel, ManyToOneRel
@@ -192,18 +191,22 @@ def _from_django_type(
             )
 
         if field.description is None:
-            if isinstance(model_field, GenericRel):
+            if isinstance(model_field, (GenericRel, GenericForeignKey)):
                 description = None
             elif isinstance(model_field, (ManyToOneRel, ManyToManyRel)):
                 description = model_field.field.help_text
             else:
-                description = model_field.help_text
+                description = getattr(model_field, "help_text")  # noqa:B009
+
             if description:
                 field.description = str(description)
 
-    # FIXME: How to properly workaround this for mutations?
-    if django_type.is_input and field.default_value is UNSET:
-        field.default = UNSET
+    if (
+        django_type.is_input
+        and field.default_value is UNSET
+        and field.default_factory is dataclasses.MISSING
+    ):
+        field.default_factory = lambda: UNSET
 
     return field
 
@@ -336,13 +339,9 @@ def _process_type(
 
 
 @dataclasses.dataclass
-class StrawberryDjangoType(Generic[_O, _M], _StraberryDjangoType):
+class StrawberryDjangoType(_StraberryDjangoType[_O, _M]):
     """Strawberry django type metadata."""
 
-    origin: _O
-    model: Type[_M]
-    is_input: bool
-    is_partial: bool
     is_filter: Union[Literal["lookups"], bool]
     order: Optional[Union[type, UnsetType]]
     filters: Optional[Union[type, UnsetType]]
